@@ -19,8 +19,8 @@
 
 namespace Doctrine\ORM;
 
-use Doctrine\Common\Persistence\ObjectManager;
 use Doctrine\ORM\Query\ResultSetMapping;
+use Doctrine\Persistence\ObjectManager;
 
 /**
  * EntityManager interface
@@ -153,6 +153,10 @@ interface EntityManagerInterface extends ObjectManager
      * @return object|null The entity reference.
      *
      * @throws ORMException
+     *
+     * @template T
+     * @psalm-param class-string<T> $entityName
+     * @psalm-return ?T
      */
     public function getReference($entityName, $id);
 
