@@ -19,6 +19,8 @@
 
 namespace Doctrine\ORM\Mapping;
 
+use function sprintf;
+
 /**
  * A MappingException indicates that something is wrong with the mapping setup.
  *
@@ -820,4 +822,16 @@ class MappingException extends \Doctrine\ORM\ORMException
             )
         );
     }
+
+    public static function illegalOverrideOfInheritedProperty($className, $propertyName)
+    {
+        return new self(
+            sprintf(
+                'Override for %s::%s is only allowed for attributes/associations ' .
+                'declared on a mapped superclass or a trait.',
+                $className,
+                $propertyName
+            )
+        );
+    }
 }
