@@ -22,6 +22,9 @@ namespace Doctrine\ORM;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\DBAL\LockMode;
 use Doctrine\ORM\Mapping\ClassMetadata;
+use Doctrine\ORM\Query\AST\DeleteStatement;
+use Doctrine\ORM\Query\AST\SelectStatement;
+use Doctrine\ORM\Query\AST\UpdateStatement;
 use Doctrine\ORM\Query\Exec\AbstractSqlExecutor;
 use Doctrine\ORM\Query\Parameter;
 use Doctrine\ORM\Query\ParameterTypeInferer;
@@ -213,9 +216,7 @@ final class Query extends AbstractQuery
     /**
      * Returns the corresponding AST for this DQL query.
      *
-     * @return \Doctrine\ORM\Query\AST\SelectStatement |
-     *         \Doctrine\ORM\Query\AST\UpdateStatement |
-     *         \Doctrine\ORM\Query\AST\DeleteStatement
+     * @return SelectStatement|UpdateStatement|DeleteStatement
      */
     public function getAST()
     {
@@ -325,7 +326,7 @@ final class Query extends AbstractQuery
             $this->evictEntityCacheRegion();
         }
 
-        list($sqlParams, $types) = $this->processParameterMappings($paramMappings);
+        [$sqlParams, $types] = $this->processParameterMappings($paramMappings);
 
         $this->evictResultSetCache(
             $executor,
@@ -364,11 +365,11 @@ final class Query extends AbstractQuery
     {
         $AST = $this->getAST();
 
-        if ($AST instanceof \Doctrine\ORM\Query\AST\SelectStatement) {
+        if ($AST instanceof SelectStatement) {
             throw new QueryException('The hint "HINT_CACHE_EVICT" is not valid for select statements.');
         }
 
-        $className = ($AST instanceof \Doctrine\ORM\Query\AST\DeleteStatement)
+        $className = $AST instanceof DeleteStatement
             ? $AST->deleteClause->abstractSchemaName
             : $AST->updateClause->abstractSchemaName;
 
@@ -380,11 +381,13 @@ final class Query extends AbstractQuery
      *
      * @param array $paramMappings
      *
-     * @return array
+     * @return mixed[][]
      *
      * @throws Query\QueryException
+     *
+     * @psalm-return array{0: list<mixed>, 1: array}
      */
-    private function processParameterMappings($paramMappings)
+    private function processParameterMappings($paramMappings) : array
     {
         $sqlParams = [];
         $types     = [];
@@ -429,7 +432,11 @@ final class Query extends AbstractQuery
         return [$sqlParams, $types];
     }
 
-    /** @return mixed[] tuple of (value, type) */
+    /**
+     * @return mixed[] tuple of (value, type)
+     *
+     * @psalm-return array{0: mixed, 1: mixed}
+     */
     private function resolveParameterValue(Parameter $parameter) : array
     {
         if ($parameter->typeWasSpecified()) {
@@ -466,9 +473,9 @@ final class Query extends AbstractQuery
      *
      * @param \Doctrine\Common\Cache\Cache|null $queryCache Cache driver.
      *
-     * @return Query This query instance.
+     * @return self This query instance.
      */
-    public function setQueryCacheDriver($queryCache)
+    public function setQueryCacheDriver($queryCache) : self
     {
         $this->_queryCache = $queryCache;
 
@@ -480,9 +487,9 @@ final class Query extends AbstractQuery
      *
      * @param boolean $bool
      *
-     * @return Query This query instance.
+     * @return self This query instance.
      */
-    public function useQueryCache($bool)
+    public function useQueryCache($bool) : self
     {
         $this->_useQueryCache = $bool;
 
@@ -509,9 +516,9 @@ final class Query extends AbstractQuery
      *
      * @param integer $timeToLive How long the cache entry is valid.
      *
-     * @return Query This query instance.
+     * @return self This query instance.
      */
-    public function setQueryCacheLifetime($timeToLive)
+    public function setQueryCacheLifetime($timeToLive) : self
     {
         if ($timeToLive !== null) {
             $timeToLive = (int) $timeToLive;
@@ -537,9 +544,9 @@ final class Query extends AbstractQuery
      *
      * @param boolean $expire Whether or not to force query cache expiration.
      *
-     * @return Query This query instance.
+     * @return self This query instance.
      */
-    public function expireQueryCache($expire = true)
+    public function expireQueryCache($expire = true) : self
     {
         $this->_expireQueryCache = $expire;
 
@@ -571,10 +578,8 @@ final class Query extends AbstractQuery
      * Sets a DQL query string.
      *
      * @param string $dqlQuery DQL Query.
-     *
-     * @return \Doctrine\ORM\AbstractQuery
      */
-    public function setDQL($dqlQuery)
+    public function setDQL($dqlQuery) : self
     {
         if ($dqlQuery !== null) {
             $this->_dql = $dqlQuery;
@@ -626,9 +631,9 @@ final class Query extends AbstractQuery
      *
      * @param int|null $firstResult The first result to return.
      *
-     * @return Query This query object.
+     * @return self This query object.
      */
-    public function setFirstResult($firstResult)
+    public function setFirstResult($firstResult) : self
     {
         $this->_firstResult = $firstResult;
         $this->_state       = self::STATE_DIRTY;
@@ -652,9 +657,9 @@ final class Query extends AbstractQuery
      *
      * @param integer|null $maxResults
      *
-     * @return Query This query object.
+     * @return self This query object.
      */
-    public function setMaxResults($maxResults)
+    public function setMaxResults($maxResults) : self
     {
         $this->_maxResults = $maxResults;
         $this->_state      = self::STATE_DIRTY;
@@ -689,6 +694,14 @@ final class Query extends AbstractQuery
         return parent::iterate($parameters, $hydrationMode);
     }
 
+    /** {@inheritDoc} */
+    public function toIterable(iterable $parameters = [], $hydrationMode = self::HYDRATE_OBJECT) : iterable
+    {
+        $this->setHint(self::HINT_INTERNAL_ITERATION, true);
+
+        return parent::toIterable($parameters, $hydrationMode);
+    }
+
     /**
      * {@inheritdoc}
      */
@@ -716,11 +729,9 @@ final class Query extends AbstractQuery
      *
      * @param int $lockMode
      *
-     * @return Query
-     *
      * @throws TransactionRequiredException
      */
-    public function setLockMode($lockMode)
+    public function setLockMode($lockMode) : self
     {
         if (in_array($lockMode, [LockMode::NONE, LockMode::PESSIMISTIC_READ, LockMode::PESSIMISTIC_WRITE], true)) {
             if ( ! $this->_em->getConnection()->isTransactionActive()) {
