@@ -108,7 +108,7 @@ class SqlWalker implements TreeWalker
     private $conn;
 
     /**
-     * @var \Doctrine\ORM\AbstractQuery
+     * @var Query
      */
     private $query;
 
@@ -143,7 +143,7 @@ class SqlWalker implements TreeWalker
      *
      * @var array
      *
-     * @psalm-var array<string, array{metadata: ClassMetadata}>
+     * @psalm-var array<string, array{metadata: ClassMetadata, token: array, relation: mixed[], parent: string}>
      */
     private $queryComponents;
 
@@ -1349,10 +1349,20 @@ class SqlWalker implements TreeWalker
 
                 $this->scalarResultAliasMap[$resultAlias] = $columnAlias;
 
-                if ( ! $hidden) {
-                    // We cannot resolve field type here; assume 'string'.
-                    $this->rsm->addScalarResult($columnAlias, $resultAlias, 'string');
+                if ($hidden) {
+                    break;
                 }
+
+                if (! $expr instanceof Query\AST\TypedExpression) {
+                    // Conceptually we could resolve field type here by traverse through AST to retrieve field type,
+                    // but this is not a feasible solution; assume 'string'.
+                    $this->rsm->addScalarResult($columnAlias, $resultAlias, 'string');
+
+                    break;
+                }
+
+                $this->rsm->addScalarResult($columnAlias, $resultAlias, $expr->getReturnType()->getName());
+
                 break;
 
             case ($expr instanceof AST\Subselect):
@@ -2080,7 +2090,9 @@ class SqlWalker implements TreeWalker
     }
 
     /**
-     * {@inheritdoc}
+     * @param mixed $inParam
+     *
+     * @return string
      */
     public function walkInParameter($inParam)
     {
