@@ -120,10 +120,7 @@ class YamlExporter extends AbstractExporter
         $array['id'] = $ids;
 
         if ($fieldMappings) {
-            if ( ! isset($array['fields'])) {
-                $array['fields'] = [];
-            }
-            $array['fields'] = array_merge($array['fields'], $fieldMappings);
+            $array['fields'] = $fieldMappings;
         }
 
         foreach ($metadata->associationMappings as $name => $associationMapping) {
