@@ -10,6 +10,7 @@ use Doctrine\ORM\PersistentCollection;
 use Doctrine\ORM\Proxy\Proxy;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\UnitOfWork;
+use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsArticle;
 use Doctrine\Tests\Models\CMS\CmsComment;
@@ -230,6 +231,10 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
         //$this->assertNull($users[0]->phonenumbers);
         //$this->assertNull($users[0]->articles);
 
+        $this->_em->clear();
+
+        IterableTester::assertResultsAreTheSame($query);
+
         $usersArray = $query->getArrayResult();
 
         $this->assertTrue(is_array($usersArray));
