@@ -8,6 +8,7 @@ use Doctrine\ORM\Event\PreFlushEventArgs;
 use Doctrine\ORM\Event\PreUpdateEventArgs;
 use Doctrine\ORM\Query;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use function sprintf;
 
 class LifecycleCallbackTest extends OrmFunctionalTestCase
 {
@@ -232,10 +233,9 @@ WHERE
     e.id IN (%s, %s)
 DQL;
 
-        $result = $this
-            ->_em
-            ->createQuery(sprintf($dql, $e1->getId(), $e2->getId()))
-            ->iterate();
+        $query = $this->_em->createQuery(sprintf($dql, $e1->getId(), $e2->getId()));
+
+        $result = $query->iterate();
 
         foreach ($result as $entity) {
             $this->assertTrue($entity[0]->postLoadCallbackInvoked);
@@ -243,6 +243,15 @@ DQL;
 
             break;
         }
+
+        $iterableResult = $query->toIterable();
+
+        foreach ($iterableResult as $entity) {
+            self::assertTrue($entity->postLoadCallbackInvoked);
+            self::assertFalse($entity->postLoadCascaderNotNull);
+
+            break;
+        }
     }
     /**
      * @group DDC-54
@@ -256,10 +265,11 @@ DQL;
         $this->_em->flush();
         $this->_em->clear();
 
-        $result = $this
-            ->_em
-            ->createQuery('SELECT e FROM Doctrine\Tests\ORM\Functional\LifecycleCallbackTestEntity AS e')
-            ->iterate(null, Query::HYDRATE_SIMPLEOBJECT);
+        $query = $this->_em->createQuery(
+            'SELECT e FROM Doctrine\Tests\ORM\Functional\LifecycleCallbackTestEntity AS e'
+        );
+
+        $result = $query->iterate(null, Query::HYDRATE_SIMPLEOBJECT);
 
         foreach ($result as $entity) {
             $this->assertTrue($entity[0]->postLoadCallbackInvoked);
@@ -267,6 +277,15 @@ DQL;
 
             break;
         }
+
+        $result = $query->toIterable([], Query::HYDRATE_SIMPLEOBJECT);
+
+        foreach ($result as $entity) {
+            self::assertTrue($entity->postLoadCallbackInvoked);
+            self::assertFalse($entity->postLoadCascaderNotNull);
+
+            break;
+        }
     }
 
     /**
