@@ -14,7 +14,7 @@ class MergeCompositeToOneKeyTest extends OrmFunctionalTestCase
     /**
      * {@inheritDoc}
      */
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
