@@ -22,7 +22,8 @@ class ResultCacheTest extends OrmFunctionalTestCase
      */
     private $cacheDataReflection;
 
-    protected function setUp() {
+    protected function setUp() : void
+    {
         $this->cacheDataReflection = new \ReflectionProperty(ArrayCache::class, "data");
         $this->cacheDataReflection->setAccessible(true);
         $this->useModelSet('cms');
