@@ -9,7 +9,7 @@ use Doctrine\Tests\Models\CMS\CmsArticle;
  */
 class DDC1129Test extends \Doctrine\Tests\OrmFunctionalTestCase
 {
-    public function setUp()
+    protected function setUp() : void
     {
         $this->useModelSet('cms');
         parent::setUp();
