@@ -24,7 +24,7 @@ class DDC117Test extends \Doctrine\Tests\OrmFunctionalTestCase
     private $translation;
     private $articleDetails;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->useModelSet('ddc117');
         parent::setUp();
