@@ -9,7 +9,7 @@ use Doctrine\ORM\UnitOfWork;
  */
 class DDC1454Test extends \Doctrine\Tests\OrmFunctionalTestCase
 {
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
