@@ -12,7 +12,7 @@ use Doctrine\Tests\Models\Company\CompanyManager;
  */
 class DDC3719Test extends \Doctrine\Tests\OrmFunctionalTestCase
 {
-    public function setUp()
+    protected function setUp() : void
     {
         $this->useModelSet('company');
         parent::setUp();
