@@ -7,7 +7,7 @@ use Doctrine\Tests\Models\CMS\CmsComment;
 
 class DDC812Test extends \Doctrine\Tests\OrmFunctionalTestCase
 {
-    protected function setUp()
+    protected function setUp() : void
     {
         $this->useModelSet('cms');
         parent::setUp();
