@@ -1,33 +1,42 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Functional;
-use Doctrine\Common\Reflection\RuntimePublicReflectionProperty;
+
+use DateTime;
+use Doctrine\Common\Reflection\RuntimePublicReflectionProperty as CommonRuntimePublicReflectionProperty;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\ReflectionEmbeddedProperty;
 use Doctrine\ORM\Query\QueryException;
+use Doctrine\Persistence\Reflection\RuntimePublicReflectionProperty;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use Exception;
+
+use function class_exists;
+use function sprintf;
 
 /**
  * @group DDC-93
  */
 class ValueObjectsTest extends OrmFunctionalTestCase
 {
-    public function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
         try {
             $this->_schemaTool->createSchema(
                 [
-                $this->_em->getClassMetadata(DDC93Person::class),
-                $this->_em->getClassMetadata(DDC93Address::class),
-                $this->_em->getClassMetadata(DDC93Vehicle::class),
-                $this->_em->getClassMetadata(DDC93Car::class),
-                $this->_em->getClassMetadata(DDC3027Animal::class),
-                $this->_em->getClassMetadata(DDC3027Dog::class),
+                    $this->_em->getClassMetadata(DDC93Person::class),
+                    $this->_em->getClassMetadata(DDC93Address::class),
+                    $this->_em->getClassMetadata(DDC93Vehicle::class),
+                    $this->_em->getClassMetadata(DDC93Car::class),
+                    $this->_em->getClassMetadata(DDC3027Animal::class),
+                    $this->_em->getClassMetadata(DDC3027Dog::class),
                 ]
             );
-        } catch(\Exception $e) {
+        } catch (Exception $e) {
         }
     }
 
@@ -35,18 +44,28 @@ class ValueObjectsTest extends OrmFunctionalTestCase
     {
         $classMetadata = $this->_em->getClassMetadata(DDC93Person::class);
 
-        $this->assertInstanceOf(RuntimePublicReflectionProperty::class, $classMetadata->getReflectionProperty('address'));
+        if (class_exists(CommonRuntimePublicReflectionProperty::class)) {
+            $this->assertInstanceOf(
+                CommonRuntimePublicReflectionProperty::class,
+                $classMetadata->getReflectionProperty('address')
+            );
+        } else {
+            $this->assertInstanceOf(
+                RuntimePublicReflectionProperty::class,
+                $classMetadata->getReflectionProperty('address')
+            );
+        }
         $this->assertInstanceOf(ReflectionEmbeddedProperty::class, $classMetadata->getReflectionProperty('address.street'));
     }
 
     public function testCRUD()
     {
-        $person = new DDC93Person();
-        $person->name = "Tara";
-        $person->address = new DDC93Address();
-        $person->address->street = "United States of Tara Street";
-        $person->address->zip = "12345";
-        $person->address->city = "funkytown";
+        $person                   = new DDC93Person();
+        $person->name             = 'Tara';
+        $person->address          = new DDC93Address();
+        $person->address->street  = 'United States of Tara Street';
+        $person->address->zip     = '12345';
+        $person->address->city    = 'funkytown';
         $person->address->country = new DDC93Country('Germany');
 
         // 1. check saving value objects works
@@ -66,10 +85,10 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->assertEquals('Germany', $person->address->country->name);
 
         // 3. check changing value objects works
-        $person->address->street = "Street";
-        $person->address->zip = "54321";
-        $person->address->city = "another town";
-        $person->address->country->name = "United States of America";
+        $person->address->street        = 'Street';
+        $person->address->zip           = '54321';
+        $person->address->city          = 'another town';
+        $person->address->country->name = 'United States of America';
         $this->_em->flush();
 
         $this->_em->clear();
@@ -82,7 +101,8 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->assertEquals('United States of America', $person->address->country->name);
 
         // 4. check deleting works
-        $personId = $person->id;;
+        $personId = $person->id;
+
         $this->_em->remove($person);
         $this->_em->flush();
 
@@ -92,12 +112,12 @@ class ValueObjectsTest extends OrmFunctionalTestCase
     public function testLoadDql()
     {
         for ($i = 0; $i < 3; $i++) {
-            $person = new DDC93Person();
-            $person->name = "Donkey Kong$i";
-            $person->address = new DDC93Address();
-            $person->address->street = "Tree";
-            $person->address->zip = "12345";
-            $person->address->city = "funkytown";
+            $person                   = new DDC93Person();
+            $person->name             = 'Donkey Kong' . $i;
+            $person->address          = new DDC93Address();
+            $person->address->street  = 'Tree';
+            $person->address->zip     = '12345';
+            $person->address->city    = 'funkytown';
             $person->address->country = new DDC93Country('United States of America');
 
             $this->_em->persist($person);
@@ -106,7 +126,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $dql = "SELECT p FROM " . __NAMESPACE__ . "\DDC93Person p";
+        $dql     = 'SELECT p FROM ' . __NAMESPACE__ . '\DDC93Person p';
         $persons = $this->_em->createQuery($dql)->getResult();
 
         $this->assertCount(3, $persons);
@@ -119,7 +139,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
             $this->assertEquals('United States of America', $person->address->country->name);
         }
 
-        $dql = "SELECT p FROM " . __NAMESPACE__ . "\DDC93Person p";
+        $dql     = 'SELECT p FROM ' . __NAMESPACE__ . '\DDC93Person p';
         $persons = $this->_em->createQuery($dql)->getArrayResult();
 
         foreach ($persons as $person) {
@@ -144,7 +164,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->_em->flush();
 
         // SELECT
-        $selectDql = "SELECT p FROM " . __NAMESPACE__ ."\\DDC93Person p WHERE p.address.city = :city AND p.address.country.name = :country";
+        $selectDql    = 'SELECT p FROM ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.address.city = :city AND p.address.country.name = :country';
         $loadedPerson = $this->_em->createQuery($selectDql)
             ->setParameter('city', 'Karlsruhe')
             ->setParameter('country', 'Germany')
@@ -159,7 +179,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         );
 
         // UPDATE
-        $updateDql = "UPDATE " . __NAMESPACE__ . "\\DDC93Person p SET p.address.street = :street, p.address.country.name = :country WHERE p.address.city = :city";
+        $updateDql = 'UPDATE ' . __NAMESPACE__ . '\\DDC93Person p SET p.address.street = :street, p.address.country.name = :country WHERE p.address.city = :city';
         $this->_em->createQuery($updateDql)
             ->setParameter('street', 'Boo')
             ->setParameter('country', 'DE')
@@ -171,7 +191,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->assertEquals('DE', $person->address->country->name);
 
         // DELETE
-        $this->_em->createQuery("DELETE " . __NAMESPACE__ . "\\DDC93Person p WHERE p.address.city = :city AND p.address.country.name = :country")
+        $this->_em->createQuery('DELETE ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.address.city = :city AND p.address.country.name = :country')
             ->setParameter('city', 'Karlsruhe')
             ->setParameter('country', 'DE')
             ->execute();
@@ -188,7 +208,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->_em->clear();
 
         // Prove that the entity was persisted correctly.
-        $dql = "SELECT p FROM " . __NAMESPACE__ ."\\DDC93Person p WHERE p.name = :name";
+        $dql = 'SELECT p FROM ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.name = :name';
 
         $person = $this->_em->createQuery($dql)
             ->setParameter('name', 'Karl')
@@ -202,7 +222,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         // Clear the EM and prove that the embeddable can be the subject of a partial query.
         $this->_em->clear();
 
-        $dql = "SELECT PARTIAL p.{id,address.city} FROM " . __NAMESPACE__ ."\\DDC93Person p WHERE p.name = :name";
+        $dql = 'SELECT PARTIAL p.{id,address.city} FROM ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.name = :name';
 
         $person = $this->_em->createQuery($dql)
             ->setParameter('name', 'Karl')
@@ -218,7 +238,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         // Clear the EM and prove that the embeddable can be the subject of a partial query regardless of attributes positions.
         $this->_em->clear();
 
-        $dql = "SELECT PARTIAL p.{address.city, id} FROM " . __NAMESPACE__ ."\\DDC93Person p WHERE p.name = :name";
+        $dql = 'SELECT PARTIAL p.{address.city, id} FROM ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.name = :name';
 
         $person = $this->_em->createQuery($dql)
             ->setParameter('name', 'Karl')
@@ -237,7 +257,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage('no field or association named address.asdfasdf');
 
-        $this->_em->createQuery("SELECT p FROM " . __NAMESPACE__ . "\\DDC93Person p WHERE p.address.asdfasdf IS NULL")
+        $this->_em->createQuery('SELECT p FROM ' . __NAMESPACE__ . '\\DDC93Person p WHERE p.address.asdfasdf IS NULL')
             ->execute();
     }
 
@@ -246,7 +266,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
         $this->expectException(QueryException::class);
         $this->expectExceptionMessage("no mapped field named 'address.asdfasdf'");
 
-        $this->_em->createQuery("SELECT PARTIAL p.{id,address.asdfasdf} FROM " . __NAMESPACE__ . "\\DDC93Person p")
+        $this->_em->createQuery('SELECT PARTIAL p.{id,address.asdfasdf} FROM ' . __NAMESPACE__ . '\\DDC93Person p')
             ->execute();
     }
 
@@ -316,7 +336,7 @@ class ValueObjectsTest extends OrmFunctionalTestCase
 
         $this->_schemaTool->createSchema(
             [
-            $this->_em->getClassMetadata(__NAMESPACE__ . '\\' . $embeddableClassName),
+                $this->_em->getClassMetadata(__NAMESPACE__ . '\\' . $embeddableClassName),
             ]
         );
     }
@@ -348,11 +368,11 @@ class DDC93Person
     /** @Embedded(class = "DDC93Timestamps") */
     public $timestamps;
 
-    public function __construct($name = null, DDC93Address $address = null)
+    public function __construct($name = null, ?DDC93Address $address = null)
     {
-        $this->name = $name;
-        $this->address = $address;
-        $this->timestamps = new DDC93Timestamps(new \DateTime);
+        $this->name       = $name;
+        $this->address    = $address;
+        $this->timestamps = new DDC93Timestamps(new DateTime());
     }
 }
 
@@ -364,7 +384,7 @@ class DDC93Timestamps
     /** @Column(type = "datetime") */
     public $createdAt;
 
-    public function __construct(\DateTime $createdAt)
+    public function __construct(DateTime $createdAt)
     {
         $this->createdAt = $createdAt;
     }
@@ -372,7 +392,6 @@ class DDC93Timestamps
 
 /**
  * @Entity
- *
  * @InheritanceType("SINGLE_TABLE")
  * @DiscriminatorColumn(name = "t", type = "string", length = 10)
  * @DiscriminatorMap({
@@ -405,9 +424,7 @@ class DDC93Car extends DDC93Vehicle
  */
 class DDC93Country
 {
-    /**
-     * @Column(type="string", nullable=true)
-     */
+    /** @Column(type="string", nullable=true) */
     public $name;
 
     public function __construct($name = null)
@@ -421,26 +438,20 @@ class DDC93Country
  */
 class DDC93Address
 {
-    /**
-     * @Column(type="string")
-     */
+    /** @Column(type="string") */
     public $street;
-    /**
-     * @Column(type="string")
-     */
+    /** @Column(type="string") */
     public $zip;
-    /**
-     * @Column(type="string")
-     */
+    /** @Column(type="string") */
     public $city;
     /** @Embedded(class = "DDC93Country") */
     public $country;
 
-    public function __construct($street = null, $zip = null, $city = null, DDC93Country $country = null)
+    public function __construct($street = null, $zip = null, $city = null, ?DDC93Country $country = null)
     {
-        $this->street = $street;
-        $this->zip = $zip;
-        $this->city = $city;
+        $this->street  = $street;
+        $this->zip     = $zip;
+        $this->city    = $city;
         $this->country = $country;
     }
 }
@@ -458,9 +469,7 @@ class DDC93Customer
 /** @Embeddable */
 class DDC93ContactInfo
 {
-    /**
-     * @Column(type="string")
-     */
+    /** @Column(type="string") */
     public $email;
     /** @Embedded(class = "DDC93Address") */
     public $address;
@@ -477,9 +486,9 @@ class DDC3028PersonWithPrefix
     /** @Embedded(class="DDC3028NestedEmbeddable", columnPrefix = "bloo_") */
     public $nested;
 
-    public function __construct(DDC3028Id $id = null, DDC3028NestedEmbeddable $nested = null)
+    public function __construct(?DDC3028Id $id = null, ?DDC3028NestedEmbeddable $nested = null)
     {
-        $this->id = $id;
+        $this->id     = $id;
         $this->nested = $nested;
     }
 }
@@ -495,9 +504,9 @@ class DDC3028PersonEmptyPrefix
     /** @Embedded(class="DDC3028NestedEmbeddable", columnPrefix = "") */
     public $nested;
 
-    public function __construct(DDC3028Id $id = null, DDC3028NestedEmbeddable $nested = null)
+    public function __construct(?DDC3028Id $id = null, ?DDC3028NestedEmbeddable $nested = null)
     {
-        $this->id = $id;
+        $this->id     = $id;
         $this->nested = $nested;
     }
 }
@@ -510,7 +519,7 @@ class DDC3028PersonPrefixFalse
     /** @Embedded(class="DDC3028Id", columnPrefix = false) */
     public $id;
 
-    public function __construct(DDC3028Id $id = null)
+    public function __construct(?DDC3028Id $id = null)
     {
         $this->id = $id;
     }
@@ -521,9 +530,7 @@ class DDC3028PersonPrefixFalse
  */
 class DDC3028Id
 {
-    /**
-     * @Id @Column(type="string")
-     */
+    /** @Id @Column(type="string") */
     public $id;
 
     public function __construct($id = null)
@@ -547,11 +554,11 @@ class DDC3028NestedEmbeddable
     public $nestedWithPrefixFalse;
 
     public function __construct(
-        DDC3028Id $nestedWithPrefix = null,
-        DDC3028Id $nestedWithEmptyPrefix = null,
-        DDC3028Id $nestedWithPrefixFalse = null
+        ?DDC3028Id $nestedWithPrefix = null,
+        ?DDC3028Id $nestedWithEmptyPrefix = null,
+        ?DDC3028Id $nestedWithPrefixFalse = null
     ) {
-        $this->nestedWithPrefix = $nestedWithPrefix;
+        $this->nestedWithPrefix      = $nestedWithPrefix;
         $this->nestedWithEmptyPrefix = $nestedWithEmptyPrefix;
         $this->nestedWithPrefixFalse = $nestedWithPrefixFalse;
     }
