@@ -8,7 +8,7 @@ class HydrationTestCase extends \Doctrine\Tests\OrmTestCase
 {
     protected $_em;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
         $this->_em = $this->_getTestEntityManager();
