@@ -28,7 +28,7 @@ class AnsiQuoteStrategyTest extends OrmTestCase
      */
     private $platform;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
