@@ -51,12 +51,11 @@ class YamlMappingDriverTest extends AbstractMappingDriverTest
 
     /**
      * @group DDC-1468
-     *
-     * @expectedException Doctrine\Persistence\Mapping\MappingException
-     * @expectedExceptionMessage Invalid mapping file 'Doctrine.Tests.Models.Generic.SerializationModel.dcm.yml' for class 'Doctrine\Tests\Models\Generic\SerializationModel'.
      */
     public function testInvalidMappingFileException()
     {
+        $this->expectException('Doctrine\Persistence\Mapping\MappingException');
+        $this->expectExceptionMessage('Invalid mapping file \'Doctrine.Tests.Models.Generic.SerializationModel.dcm.yml\' for class \'Doctrine\Tests\Models\Generic\SerializationModel\'.');
         $this->createClassMetadata(SerializationModel::class);
     }
 
@@ -86,9 +85,8 @@ class YamlMappingDriverTest extends AbstractMappingDriverTest
     public function testDeprecation() : void
     {
         $this->createClassMetadata(DDC2069Entity::class);
-        $this->expectDeprecationMessage('YAML mapping driver is deprecated and will be removed in Doctrine ORM 3.0, please migrate to annotation or XML driver.');
+        $this->expectDeprecationMessageSame('YAML mapping driver is deprecated and will be removed in Doctrine ORM 3.0, please migrate to annotation or XML driver.');
     }
-
 }
 
 class DDC2069Entity
