@@ -26,7 +26,7 @@ class JoinedSubClassPersisterTest extends OrmTestCase
     /**
      * {@inheritDoc}
      */
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
