@@ -46,7 +46,7 @@ class ProxyFactoryTest extends OrmTestCase
     /**
      * {@inheritDoc}
      */
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
         $this->connectionMock = new ConnectionMock([], new DriverMock());
