@@ -32,7 +32,7 @@ class InfoCommandTest extends OrmFunctionalTestCase
      */
     private $tester;
 
-    protected function setUp()
+    protected function setUp() : void
     {
         parent::setUp();
 
@@ -49,8 +49,8 @@ class InfoCommandTest extends OrmFunctionalTestCase
     {
         $this->tester->execute(['command' => $this->command->getName()]);
 
-        self::assertContains(AttractionInfo::class, $this->tester->getDisplay());
-        self::assertContains(City::class, $this->tester->getDisplay());
+        self::assertStringContainsString(AttractionInfo::class, $this->tester->getDisplay());
+        self::assertStringContainsString(City::class, $this->tester->getDisplay());
     }
 
     public function testEmptyEntityClassNames() :  void
@@ -77,12 +77,12 @@ class InfoCommandTest extends OrmFunctionalTestCase
 
         $tester->execute(['command' => $command->getName()]);
 
-        self::assertContains(
+        self::assertStringContainsString(
             ' ! [CAUTION] You do not have any mapped Doctrine ORM entities according to the current configuration',
             $tester->getDisplay()
         );
 
-        self::assertContains(
+        self::assertStringContainsString(
             ' !           If you have entities or mapping files you should check your mapping configuration for errors.',
             $tester->getDisplay()
         );
@@ -116,7 +116,7 @@ class InfoCommandTest extends OrmFunctionalTestCase
 
         $tester->execute(['command' => $command->getName()]);
 
-        self::assertContains('[FAIL] InvalidEntity', $tester->getDisplay());
-        self::assertContains('exception message', $tester->getDisplay());
+        self::assertStringContainsString('[FAIL] InvalidEntity', $tester->getDisplay());
+        self::assertStringContainsString('exception message', $tester->getDisplay());
     }
 }
